@@ -1,6 +1,7 @@
 #######################################################
 #	apc package
-#	Bent Nielen, 19 September 2016, version 1.2.3
+#	Bent Nielsen, 25 Jun 2025, version 3.0.0
+#	Bent Nielsen, 19 September 2016, version 1.2.3
 #	functions to fit model
 #######################################################
 #	Copyright 2014-2016 Bent Nielsen
@@ -25,6 +26,7 @@
 #	apc.get.design.collinear
 #########################################################
 apc.get.design.collinear	<- function(apc.index)
+#	BN 9 Dec 2023 updated to included mixed frequency
 #	BN 1 April 2015
 #	Constructs a collinear design matrix for an apc model.
 #	It includes columns for intercept,
@@ -47,34 +49,121 @@ apc.get.design.collinear	<- function(apc.index)
 	per.odd		<- apc.index$per.odd
 	U			<- apc.index$U
 	n.data		<- apc.index$n.data
+	unit		<- apc.index$unit			# BN 7 Dec 2023 for mixed
+	data.format	<- apc.index$data.format	# BN 7 Dec 2023 for mixed
 	########################
-	#	declaring design matrix
-	p.design.collinear	<- age.max+per.max+coh.max-2
-	  design.collinear	<- matrix(data=0,nrow=n.data,ncol=p.design.collinear)
+	#	BN 7 Dec 2023
+	#	types of data format
+	data.format.list.regular<- c("AP","AC","CA","CL","CP","PA","PC","trap","trapezoid")
+	data.format.list.mixed	<- c("APm","PAm")
 	########################
 	# 	construction of design matrix
-	for(row in 1:n.data)
-	{
-		age	<- index.trap[row,1]		#	age
-		coh	<- index.trap[row,2]		#	cohort
-		per	<- age+coh-1
-		design.collinear[row,1]	<- 1
-		design.collinear[row,2]	<- age-U
-		design.collinear[row,4]	<- coh-U
-		design.collinear[row,3]	<- design.collinear[row,2]+design.collinear[row,4]
-		if(age<U)
-			design.collinear[row,(4+age):(4+U-1)]										<- seq(1,U-age)
-		if(age>U+1)
-			design.collinear[row,(4+U):(4+U+age-U-2)]									<- seq(age-U-1,1)
-		if(per.odd && per==2*(U-1))
-			design.collinear[row,(2+age.max+1)]											<- 1
-		if(per>2*U)
-			design.collinear[row,(2+age.max+per.odd+1):(2+age.max+per.odd+per-2*U)]		<- seq(per-2*U,1)
-		if(coh<U)
-			design.collinear[row,(age.max+per.max+coh):(age.max+per.max+U-1)]			<- seq(1,U-coh)
-		if(coh>U+1)
-			design.collinear[row,(age.max+per.max+U):(age.max+per.max+U+coh-U-2)]		<- seq(coh-U-1,1)
- 	}
+	#	regular case
+	if(data.format %in% data.format.list.regular)	{
+		p.design.collinear	<- age.max+per.max+coh.max-2
+		design.collinear	<- matrix(data=0,nrow=n.data,ncol=p.design.collinear)
+		for(row in 1:n.data)	{
+			age	<- index.trap[row,1]		#	age
+			coh	<- index.trap[row,2]		#	cohort
+			per	<- age+coh-1
+			design.collinear[row,1]	<- 1
+			design.collinear[row,2]	<- age-U
+			design.collinear[row,4]	<- coh-U
+			design.collinear[row,3]	<- design.collinear[row,2]+design.collinear[row,4]
+			if(age<U)
+				design.collinear[row,(4+age):(4+U-1)]										<- seq(1,U-age)
+			if(age>U+1)
+				design.collinear[row,(4+U):(4+U+age-U-2)]									<- seq(age-U-1,1)
+			if(per.odd && per==2*(U-1))
+				design.collinear[row,(2+age.max+1)]											<- 1
+			if(per>2*U)
+				design.collinear[row,(2+age.max+per.odd+1):(2+age.max+per.odd+per-2*U)]		<- seq(per-2*U,1)
+			if(coh<U)
+				design.collinear[row,(age.max+per.max+coh):(age.max+per.max+U-1)]			<- seq(1,U-coh)
+			if(coh>U+1)
+				design.collinear[row,(age.max+per.max+U):(age.max+per.max+U+coh-U-2)]		<- seq(coh-U-1,1)
+ 	}}
+	########################
+	#	BN 10 Dec 2023
+	# 	construction of design matrix
+	#	mixed case
+	#	there will be
+	#		1 overall level
+	# 		H age-cohort slopes
+	#		G period-cohort slopes
+	#		age.max-H-1  age 	double differences
+	#		per.max-G-1  period double differences
+	#		coh.max	     cohort double differences (running from 1 to C)
+	if(data.format %in% data.format.list.mixed)	{
+		p.design.collinear	<- age.max+per.max+coh.max-1		
+		design.collinear	<- matrix(data=0,nrow=n.data,ncol=p.design.collinear)
+		G	<- unit[2];
+		H	<- unit[3];
+		A	<- age.max*G;
+		p0.age	<- 1+G+H				# 	#elements in intercept and slopes
+		p0.per	<- p0.age+age.max-H-1	#	#elements in intercept and slopes and DDalpha_age
+		p0.coh	<- p0.per+per.max-G-1	#	#elements in intercept and slopes and DDalpha_age and DDbeta_per
+		names	<-	c("1",
+						paste("la",as.character(1:H),sep=""),
+						paste("nu" ,as.character(1:G),sep=""),
+						paste("DDa",as.character(((H+2):age.max)*G),sep=""),
+						paste("DDb",as.character(((G+2):per.max)*H),sep=""),
+						paste("DDc",as.character(1:coh.max),sep=""))
+		colnames(design.collinear)	<- names
+		for(row in 1:n.data)	{
+			g	<- age.max-index.trap[row,1]		#	g, so that age=A-g*G 
+			h	<- index.trap[row,2]-1				#	h, so that per=H+h*H 
+			coh	<- H+h*H+g*G						#   per+A-age=H+h*H+g*G
+			q.g <- g %/% H
+			r.g	<- g %% H
+			q.h	<- h %/% G
+			r.h <- h %% G					
+			#	M^intercept
+			design.collinear[row,1]	<- 1
+			if(r.g>0)	{
+				design.collinear[row,1+r.g]		<- 1	}
+			if(r.h>0)	{
+				design.collinear[row,1+H+r.h]	<- 1	}
+			if(r.g*r.h>0)	{
+				entries	<- p0.coh+H+c(function.coin.array(G,H,r.g,r.h));
+				design.collinear[row,entries]	<- 1	}
+			#	M^slope age-coh
+			design.collinear[row,1+H]	<- q.g
+			if(r.h>0)	{
+				entries	<- p0.coh+H+(c(function.coin.array(G,H,H,r.h))+r.g*G);
+				design.collinear[row,entries]	<- design.collinear[row,entries]+q.g	}
+			if(r.g>0)	{
+				entries	<- p0.coh+H+ c(function.coin.array(G,H,r.g,G));
+				design.collinear[row,entries]	<- design.collinear[row,entries]+q.g;
+				entries	<- p0.per+1- (1:r.g); 
+				design.collinear[row,entries]	<- design.collinear[row,entries]+q.g	}
+			#	M^slope age-per
+			design.collinear[row,1+H+G]	<- q.h
+			if(r.g>0)	{
+				entries	<- p0.coh+H+(c(function.coin.array(G,H,r.g,G))+r.h*H);
+				design.collinear[row,entries]	<- design.collinear[row,entries]+q.h	}
+			if(r.h>0)	{
+				entries	<- p0.coh+H+ c(function.coin.array(G,H,H,r.h));
+				design.collinear[row,entries]	<- design.collinear[row,entries]+q.h;
+				entries	<- p0.per+ (1:r.h); 
+				design.collinear[row,entries]	<- design.collinear[row,entries]+q.h	}
+			#	S^age
+			if(q.g>1)	{
+				for(t in 0:(q.g-2))	{
+					entries	<- p0.per+1-t*H-r.g-(1:H); 
+					design.collinear[row,entries]	<- design.collinear[row,entries]+q.g-1-t	}}
+			#	S^per
+			if(q.h>1)	{
+				for(t in 0:(q.h-2))	{
+					entries	<- p0.per+t*G+r.h+(1:G);
+					design.collinear[row,entries]	<- design.collinear[row,entries]+q.h-1-t	}}
+			#	S^coh
+			if(q.g+q.h>1)	{
+				for(t in 0:(q.g+q.h-2))	{
+					entries	<- p0.coh+H+t*G*H+r.g*G+r.h*H+c(function.coin.array(G,H,H,G));
+					design.collinear[row,entries]	<- design.collinear[row,entries]+q.g+q.h-1-t	}}
+ 	}}
+	########################
 	return(design.collinear)
 }	# 	apc.get.design.collinear
 
@@ -82,10 +171,18 @@ apc.get.design.collinear	<- function(apc.index)
 #	apc.get.design
 #########################################################
 apc.get.design	<- function(apc.index,model.design=NULL)
-#	BN 27 Aug 2014
+#	BN 11 Dec 2023:	added mixed frequency
 #	BN 28 Sep 2016 (7 Sep 2015): added model designs: "-A", "-P", "-C"
+#	BN 27 Aug 2014
 #	Constructs design matrix for an apc model or sub-model thereof.
 #	In:		apc.index or apc.fit		List of indices etc.
+#                                       but uses only
+#                                        	apc.index$age.max				
+#                                        	apc.index$per.max				
+#                                        	apc.index$coh.max
+#                                        	apc.index$unit			
+#                                        	apc.index$data.format
+#                                        	apc.index$model.design
 #			model.design				Character. Indicates which sub-model should be fitted.
 #										Default is NULL. Possible choices:
 #										"APC","AP","AC","PC","Ad","Pd","Cd","A","P","C","t","tA","tP","tC","1"
@@ -117,6 +214,13 @@ apc.get.design	<- function(apc.index,model.design=NULL)
 	age.max		<- apc.index$age.max				
 	per.max		<- apc.index$per.max				
 	coh.max		<- apc.index$coh.max
+	unit		<- apc.index$unit			# BN 11 Dec 2023 for mixed
+	data.format	<- apc.index$data.format	# BN 11 Dec 2023 for mixed
+	########################
+	#	BN 11 Dec 2023
+	#	types of data format
+	data.format.list.regular<- c("AP","AC","CA","CL","CP","PA","PC","trap","trapezoid")
+	data.format.list.mixed	<- c("APm","PAm")
 	##############################
 	#	construct indicators for slope parameters and double difference parameters
 	#	depending on model.design choice
@@ -152,14 +256,59 @@ apc.get.design	<- function(apc.index,model.design=NULL)
 	if(model.design=="-dPC"){   constant<-0; slopes <- c(0,0,1); difdif <- c(0,1,1);	}
 	if(model.design=="-tA") {   constant<-0; slopes <- c(1,0,0); difdif <- c(0,0,0);	}
 	if(model.design=="-tC") {   constant<-0; slopes <- c(0,0,1); difdif <- c(0,0,0);	}
-	##############################
+	########################
+	#	BN 11 Dec 2023
+	#	mixed frequency: update slopes
+	if(data.format %in% data.format.list.mixed)
+	{
+		if(model.design=="APC")	{	slopes <- c(1,1,0); 	}
+		if(model.design=="AP" )	{	slopes <- c(1,1,0); 	}
+		if(model.design=="AC" )	{	slopes <- c(1,1,0); 	}
+		if(model.design=="PC" )	{	slopes <- c(1,1,0); 	}
+		if(model.design=="Ad" )	{	slopes <- c(1,1,0); 	}
+		if(model.design=="Pd" )	{	slopes <- c(1,1,0); 	}
+		if(model.design=="Cd" )	{	slopes <- c(1,1,0); 	}
+		if(model.design=="A"  )	{	slopes <- c(1,0,0); 	}
+		if(model.design=="P"  )	{	slopes <- c(0,1,0); 	}
+		if(model.design=="C"  )	{	slopes <- c(0,1,0); 	}
+		if(model.design=="t"  )	{	slopes <- c(1,1,0); 	}
+		if(model.design=="tA" )	{	slopes <- c(1,0,0); 	}
+		if(model.design=="tP" )	{	slopes <- c(0,1,0); 	}
+		if(model.design=="tC" )	{	slopes <- c(0,1,0); 	}
+		if(model.design=="1"  )	{	slopes <- c(0,0,0); 	}
+	}	
+	########################
+	#	BN 11 Dec 2023
+	#	mixed frequency: update slopes
 	#	construct index for selecting columns of design matrix
-	index.design	<- c(1)
-	for(i in 1:3)	if(slopes[i])	index.design	<- c(index.design,i+1)
-	if(difdif[1])	index.design <- c(index.design,4+seq(1:(age.max-2)))	
-	if(difdif[2])	index.design <- c(index.design,2+age.max+seq(1:(per.max-2)))	
-	if(difdif[3])	index.design <- c(index.design,  age.max+per.max+seq(1:(coh.max-2)))
-	if(constant==0)	index.design <- index.design[2:length(index.design)]
+	if(data.format %in% data.format.list.regular)	{
+		G	<- H	<- 1;
+		index.design	<- c(1);
+		for(i in 1:3)	if(slopes[i])	index.design	<- c(index.design,i+1);
+		if(difdif[1])	index.design <- c(index.design,4+seq(1:(age.max-2)));	
+		if(difdif[2])	index.design <- c(index.design,2+age.max+seq(1:(per.max-2)));	
+		if(difdif[3])	index.design <- c(index.design,  age.max+per.max+seq(1:(coh.max-2)));
+		if(constant==0)	index.design <- index.design[2:length(index.design)];
+		}
+	if(data.format %in% data.format.list.mixed)	{	# 11 Dec 2023
+		G	<- unit[2];
+		H	<- unit[3];
+		A	<- age.max*G;
+		P	<- per.max*H;
+		C	<- A+P-G;
+		p0.age	<- 1+G+H;				# 	#elements in intercept and slopes
+		p0.per	<- p0.age+age.max-H-1;	#	#elements in intercept and slopes and DDalpha_age
+		p0.coh	<- p0.per+per.max-G-1;	#	#elements in intercept and slopes and DDalpha_age and DDbeta_per
+		N.coh	<- function.coin(G,H)$non.representable;
+		I0.coh	<- setdiff((G+2*H):C,c(C-N.coh,G+2*H+N.coh));
+		index.design	<- c(1);
+		if(slopes[1])	index.design	<- c(index.design,1+(1:H));
+		if(slopes[2])	index.design	<- c(index.design,1+(1:G)+slopes[1]*H);
+		if(difdif[1])	index.design	<- c(index.design,p0.age+1:(age.max-H-1));
+		if(difdif[2])	index.design	<- c(index.design,p0.per+1:(per.max-G-1));
+		if(difdif[3])	index.design	<- c(index.design,p0.coh+I0.coh);
+		}
+		
 	##############################
 	#	get design matrix
 	design	<- apc.get.design.collinear(apc.index)[,index.design]
@@ -175,6 +324,7 @@ apc.get.design	<- function(apc.index,model.design=NULL)
 #	apc.fit.model
 #########################################################
 apc.fit.model	<- function(apc.data.list,model.family,model.design,apc.index=NULL,replicate.version.1.3.1=FALSE)
+#	BN 11 dec 2023: added mixed frequency
 #	BN 10 may 2016	od.poisson.response correction to coefficients.canonical
 #	BN 14 apr 2016	Added predictors
 #	BN  2 feb 2016	Changed: parameter label: date to character changed to allow nice decimal points
@@ -236,6 +386,8 @@ apc.fit.model	<- function(apc.data.list,model.family,model.design,apc.index=NULL
 {	#	apc.fit.model
 	##############################
 	#	check input
+	data.format.list.regular<- c("AP","AC","CA","CL","CP","PA","PC","trap","trapezoid")	# BN 11 Dec 2023
+	data.format.list.mixed	<- c("APm","PAm")											# BN 11 Dec 2023
 	model.design.list		<- c("APC","AP","AC","PC","Ad","Pd","Cd","A","P","C","t","tA","tP","tC","1")
 	model.family.list		<- c("binomial.dose.response","poisson.response","od.poisson.response","poisson.dose.response","gaussian.rates","gaussian.response","log.normal.rates","log.normal.response")
 	model.family.gaussian	<- c("gaussian.rates","gaussian.response","log.normal.rates","log.normal.response")
@@ -248,25 +400,27 @@ apc.fit.model	<- function(apc.data.list,model.family,model.design,apc.index=NULL
 	#	get index
 	if(is.null(apc.index)==TRUE)
 		apc.index	<- apc.get.index(apc.data.list)
-	##############################
+	############################## 
 	#	create indicator for mixed parametrisation
 	mixed.par	<- (1-isTRUE(model.design=="1"))*isTRUE(model.family %in% model.family.mixed)
 	mixed.par.1	<-    isTRUE(model.design=="1") *isTRUE(model.family %in% model.family.mixed)
 	##############################
 	#	get values, that are used
-	age.max		<- apc.index$age.max				
-	per.max		<- apc.index$per.max				
-	coh.max		<- apc.index$coh.max
-	age1		<- apc.index$age1    
-	per1		<- apc.index$per1
-	coh1		<- apc.index$coh1    
-	unit		<- apc.index$unit
-	per.zero	<- apc.index$per.zero
+	age.max			<- apc.index$age.max				
+	per.max			<- apc.index$per.max				
+	coh.max			<- apc.index$coh.max
+	age1				<- apc.index$age1    
+	per1				<- apc.index$per1
+	coh1				<- apc.index$coh1    
+	unit				<- apc.index$unit
+	per.zero		<- apc.index$per.zero
+	index.data	<- apc.index$index.data			 	
 	index.trap	<- apc.index$index.trap
-	n.data		<- apc.index$n.data
-	v.response	<- apc.index$response[apc.index$index.data]
-	v.dose		<- apc.index$dose[    apc.index$index.data]
-	n.decimal	<- apc.index$n.decimal
+	n.data			<- apc.index$n.data
+	v.response	<- apc.index$response[index.data]
+	v.dose			<- apc.index$dose[    index.data]
+	n.decimal		<- apc.index$n.decimal
+	data.format	<- apc.index$data.format			# BN 11 Dec 2023
 	##############################
 	#	get design
 	#		design matrix 
@@ -305,38 +459,100 @@ apc.fit.model	<- function(apc.data.list,model.family,model.design,apc.index=NULL
 		fit	<- glm.fit(design,log(v.response),family=gaussian(link="identity"))
 	#	Gaussian regression for log(rates) and with identity link (Least Squares)
 	if(model.family=="log.normal.rates")
-		fit	<- glm.fit(design,log(v.response/v.dose),family=gaussian(link="identity"))		
+		fit	<- glm.fit(design,log(v.response/v.dose),family=gaussian(link="identity"))
+	########################
+ 	#	BN 25 Jun 2025
+	# Construct
+	#		indices and dates for double differences,
+	#		row names for canonical parameter
+	#	Different methods for regular and mixed data formats.
+	########################
+ 	#	BN 25 Jun 2025
+	#	Regular data format
+	#		indices and dates for double differences,
+	#		row names for canonical parameter
+	#	Uses code from 2014
+	########################
+	if(data.format %in% data.format.list.regular) {	# regular data format
+		##############################
+		#	construct for indices for double difference parameters  
+		index.age	<- NULL
+		index.per	<- NULL
+		index.coh	<- NULL
+		start		<- 1+sum(slopes)
+		if(difdif[1])	{	index.age	<- start+seq(1,age.max-2);	start	<- start+age.max-2	}
+		if(difdif[2])	{	index.per	<- start+seq(1,per.max-2);	start	<- start+per.max-2	}
+		if(difdif[3])	{	index.coh	<- start+seq(1,coh.max-2);	start	<- start+coh.max-2	}
+		xi.dim		<- start
+		##############################
+		#	construct dates for for double difference parameters
+		dates		<- matrix(data=NA,nrow=xi.dim,ncol=1)			
+		if(difdif[1])	dates[index.age,1]	<- age1+seq(2,age.max-1)*unit[1]	# 24 Jun 2025, unit updated	
+		if(difdif[2])	dates[index.per,1]	<- per1+seq(2,per.max-1)*unit[1]							
+		if(difdif[3])	dates[index.coh,1]	<- coh1+seq(2,coh.max-1)*unit[1]
+		##############################
+		#	construct row names for canonical parameter
+		names	<- c("level")
+		if(slopes[1])	names	<- c(names,"age slope")
+		if(slopes[2])	names	<- c(names,"period slope")
+		if(slopes[3])	names	<- c(names,"cohort slope")
+		if(difdif[1])
+			for(i in 1:(age.max-2))
+				names	<- c(names,paste("DD_age_"   ,apc.internal.function.date.2.character((dates[index.age,1])[i],n.decimal),sep=""))
+				if(difdif[2])
+			for(i in 1:(per.max-2))
+				names	<- c(names,paste("DD_period_",apc.internal.function.date.2.character((dates[index.per,1])[i],n.decimal),sep=""))
+		if(difdif[3])
+			for(i in 1:(coh.max-2))
+				names	<- c(names,paste("DD_cohort_",apc.internal.function.date.2.character((dates[index.coh,1])[i],n.decimal),sep=""))
+	}	# regular data format
+	########################
+ 	#	BN 25 Jun 2025
+	#	Mixed data format
+	#	Covers only APm and PAm data formats
+	#		indices and dates for double differences,
+	#		row names for canonical parameter
+	#	Uses code from 2023
+	########################
+	if(data.format %in% data.format.list.mixed)	{	# mixed data format
+		#	some derived values
+		G	<- unit[2];
+		H	<- unit[3];
+		A	<- age.max*G;		# maximum age value 
+		P	<- per.max*H;		# maximum per value 
+		C	<- A+P-G				# maximum coh value
+		N.coh	<- function.coin(G,H)$non.representable
+		I.coh	<- setdiff((	H):C,c(C-N.coh,G+2*H+N.coh))	  
+		I0.coh	<- setdiff((G+2*H):C,c(C-N.coh,G+2*H+N.coh))	  
+		##############################
+		#	construct for indices for double difference parameters  
+		index.age	<- NULL
+		index.per	<- NULL
+		index.coh	<- NULL
+		start		<- 1+slopes[1]*G+slopes[2]*H+slopes[3]													# BN 11 Dec 2023
+		if(difdif[1])	{	index.age	<- start+seq(1,age.max-H-1);	start	<- start+age.max-H-1	}	# BN 19 Dec 2023
+		if(difdif[2])	{	index.per	<- start+seq(1,per.max-G-1);	start	<- start+per.max-G-1	}	# BN 19 Dec 2023
+		if(difdif[3])	{	index.coh	<- start+seq(1,length(I0.coh));
+							index.coh.dd	<- start+I0.coh-G-2*H+1;	start	<- start+length(I0.coh)	}	# BN 19 Dec 2023
+		xi.dim		<- start
+		##############################
+		#	construct dates for for double difference parameters
+		dates		<- matrix(data=NA,nrow=xi.dim,ncol=1)			
+		if(difdif[1])	dates[index.age,1]		<- age1+seq(H+1,age.max-1)*G*unit[1]
+		if(difdif[2])	dates[index.per,1]		<- per1+seq(G+1,per.max-1)*H*unit[1]
+		if(difdif[3])	dates[index.coh.dd,1]	<- coh1+        (I0.coh-1)  *unit[1]
+		##############################
+		#	construct row names for canonical parameter
+		names	<- c("level")
+		if(slopes[1])	{	names	<- c(names,paste("age_slope_",as.character(1:H),sep=""))	};
+		if(slopes[2])	{	names	<- c(names,paste("per_slope_",as.character(1:G),sep=""))	};
+		#	12 Dec 2023 	
+		if(difdif[1])	{	names	<- c(names,paste("D",as.character(G*H),"D",as.character(G),"_age_",apc.internal.function.date.2.character(dates[index.age   ,1]),sep=""))	};	
+		if(difdif[2])	{	names	<- c(names,paste("D",as.character(G*H),"D",as.character(H),"_per_",apc.internal.function.date.2.character(dates[index.per   ,1]),sep=""))	};	
+		if(difdif[3])	{	names	<- c(names,paste("D",as.character(G)  ,"D",as.character(H),"_coh_",apc.internal.function.date.2.character(dates[index.coh.dd,1]),sep=""))	};	
+	} # mixed data format
 	##############################
-	#	construct for indices for double difference parameters  
-	index.age	<- NULL
-	index.per	<- NULL
-	index.coh	<- NULL
-	start		<- 1+sum(slopes)
-	if(difdif[1])	{	index.age	<- start+seq(1,age.max-2);	start	<- start+age.max-2	}
-	if(difdif[2])	{	index.per	<- start+seq(1,per.max-2);	start	<- start+per.max-2	}
-	if(difdif[3])	{	index.coh	<- start+seq(1,coh.max-2);	start	<- start+coh.max-2	}
-	xi.dim		<- start
-	##############################
-	#	construct dates for for double difference parameters
-	dates		<- matrix(data=NA,nrow=xi.dim,ncol=1)			
-	if(difdif[1])	dates[index.age,1]	<- age1+seq(2,age.max-1)*unit	
-	if(difdif[2])	dates[index.per,1]	<- per1+seq(2,per.max-1)*unit
-	if(difdif[3])	dates[index.coh,1]	<- coh1+seq(2,coh.max-1)*unit
-	##############################
-	#	construct row names for canonical parameter
-	names	<- c("level")
-	if(slopes[1])	names	<- c(names,"age slope")
-	if(slopes[2])	names	<- c(names,"period slope")
-	if(slopes[3])	names	<- c(names,"cohort slope")
-	if(difdif[1])
-		for(i in 1:(age.max-2))
-			names	<- c(names,paste("DD_age_"   ,apc.internal.function.date.2.character((dates[index.age,1])[i],n.decimal),sep=""))
-			if(difdif[2])
-		for(i in 1:(per.max-2))
-			names	<- c(names,paste("DD_period_",apc.internal.function.date.2.character((dates[index.per,1])[i],n.decimal),sep=""))
-	if(difdif[3])
-		for(i in 1:(coh.max-2))
-			names	<- c(names,paste("DD_cohort_",apc.internal.function.date.2.character((dates[index.coh,1])[i],n.decimal),sep=""))
+	#	Return to general code covering both regular and mixed data format
 	##############################
 	#	Get coefficients and covariance
 	coefficients.canonical	<- summary.glm(fit)$coefficients
@@ -389,33 +605,45 @@ apc.fit.model	<- function(apc.data.list,model.family,model.design,apc.index=NULL
 	#	predictors 14 apr 2016	
 	predictors	<- (design %*% summary.glm(fit)$coefficients)[,1]
 	##############################
-	return(c(fit,apc.index,
-				list(	model.family				= model.family					,
-						model.design				= model.design					,
-						coefficients.canonical		= coefficients.canonical		,
-						covariance.canonical		= covariance.canonical			,
-						slopes						= slopes						,
-						difdif						= difdif						,
-						index.age					= index.age 					,
-						index.per					= index.per 					,
-						index.coh					= index.coh 					,
-						dates						= dates							,
-						RSS							= RSS							,
-						sigma2						= sigma2						,
-						s2							= s2							,
-						n.decimal					= n.decimal						,
-						predictors					= predictors			
-			)))	
+	#	return
+	# BN 25 jun 2025 reorganized returned list
+	l.return 	<- c(fit,apc.index,
+			list(	model.family						= model.family					,
+						model.design						= model.design					,
+						coefficients.canonical	= coefficients.canonical,
+						covariance.canonical		= covariance.canonical	,
+						slopes									= slopes								,
+						difdif									= difdif								,
+						index.age								= index.age 						,
+						index.per								= index.per 						,
+						index.coh								= index.coh 						,
+						dates										= dates									,
+						RSS											= RSS										,
+						sigma2									= sigma2								,
+						s2											= s2										,
+						n.decimal								= n.decimal							,
+						predictors							= predictors			
+						))		
+	if(data.format %in% data.format.list.mixed)	{	# mixed data format
+		l.return	<- c(l.return,
+			list(	I0.coh									= I0.coh 								,
+						I.coh										= I.coh						
+						))
+	}					
+	return(l.return)
 }	#	apc.fit.model
 
 #########################################################
 #	apc.fit.table
 #########################################################
-apc.fit.table	<- function(apc.data.list,model.family,model.design.reference="APC",apc.index=NULL)
+apc.fit.table	<- function(apc.data.list,model.family,model.design.reference="APC",apc.index=NULL,digits=3)
+#	BN 11 dec 2023: added mixed frequency, digits
 #	BN 10 mar 2018: added F test to gaussian family
 #	BN 17 may 2016: labels corrected
 #	BN 10 may 2016: reference model introduced
 #	BN 17 mar 2015
+#	In		digits				Numeric.  Number of digits in output
+#								Default 3.
 {	#	apc.fit.table
 	######################
 	#	model families
@@ -423,7 +651,6 @@ apc.fit.table	<- function(apc.data.list,model.family,model.design.reference="APC
 	model.family.od			<- c("od.poisson.response")
 	model.family.other		<- c("binomial.dose.response","poisson.response","poisson.dose.response")
 	model.family.list		<- c(model.family.gaussian,model.family.od,model.family.other)
-
 	######################
 	#	check input
 	if(isTRUE(model.family %in% model.family.list)==FALSE)
@@ -469,14 +696,14 @@ apc.fit.table	<- function(apc.data.list,model.family,model.design.reference="APC
 			p.F.gauss	<- pf(F.gauss,df,df.U,lower.tail=FALSE)
 		}	
 		if(model.family %in% model.family.gaussian)
-			#	-2logL , df , LR , df.res , p.LR , F , p.F, aic	 = 8
-			return(round(c(dev.R,df.R,LR,df,p.LR,F.gauss,p.F.gauss,aic),digits=3))
+			#	-2logL , df , LR , df.res , p.LR , F , p.F, aic, RSS, s = 10
+			return(round(c(dev.R,df.R,LR,df,p.LR,F.gauss,p.F.gauss,aic,RSS.R,sqrt(RSS.R/df.R)),digits=digits))
 		if(model.family  %in% model.family.od)
 			#	dev    , df , F.odp , df.res, p.F.odp			 = 6
-			return(round(c(dev.R,df.R,p.dev,F.odp,df,p.F.odp),digits=3))
+			return(round(c(dev.R,df.R,p.dev,F.odp,df,p.F.odp),digits=digits))
 		if(model.family  %in% model.family.other)
 			#	dev		, df , LR , df.res , p.LR , aic			 = 7	
-			return(round(c(dev.R,df.R,p.dev,LR,df,p.LR,aic),digits=3))
+			return(round(c(dev.R,df.R,p.dev,LR,df,p.LR,aic),digits=digits))
 	}
 	######################
 	if(model.design.reference=="APC")	model.design.list	<- c("APC","AP","AC","PC","Ad","Pd","Cd","A","P","C","t","tA","tP","tC","1")
@@ -492,7 +719,7 @@ apc.fit.table	<- function(apc.data.list,model.family,model.design.reference="APC
 	if(model.design.reference=="t")		model.design.list	<- c(				 								 "t","tA","tP","tC","1")
 	######################	
 	#	number of columns
-		if(isTRUE(model.family %in% model.family.gaussian))	ncol <- 8
+		if(isTRUE(model.family %in% model.family.gaussian))	ncol <- 10	# changed from 8 to 10 to include RSS and sigma^2
 		if(isTRUE(model.family %in% model.family.od))		ncol <- 6
 		if(isTRUE(model.family %in% model.family.other))	ncol <- 7
 	######################
@@ -510,7 +737,7 @@ apc.fit.table	<- function(apc.data.list,model.family,model.design.reference="APC
 	rownames(fit.tab)	<- model.design.list
 	#	column names
 	if(isTRUE(model.family %in% model.family.gaussian))
-		colnames(fit.tab)	<- c("-2logL","df.residual",paste("LR vs.",model.design.reference,sep=""),paste("df vs.",model.design.reference,sep=""),"prob(>chi_sq)",paste("F vs.",model.design.reference,sep=""),"prob(>F)","aic")
+		colnames(fit.tab)	<- c("-2logL","df.residual",paste("LR vs.",model.design.reference,sep=""),paste("df vs.",model.design.reference,sep=""),"prob(>chi_sq)",paste("F vs.",model.design.reference,sep=""),"prob(>F)","aic","RSS","sigma")
 	if(isTRUE(model.family %in% model.family.od))
 		colnames(fit.tab)	<- c("deviance","df.residual","prob(>chi_sq)",paste("F vs.",model.design.reference,sep=""),paste("df vs.",model.design.reference,sep=""),"prob(>F)")
 	if(isTRUE(model.family %in% model.family.other))
@@ -518,7 +745,7 @@ apc.fit.table	<- function(apc.data.list,model.family,model.design.reference="APC
 	######################
 	return(fit.tab)
 }	#	apc.fit.table
-# 	new.apc.fit.table(data,"od.poisson.response")
+# 	apc.fit.table(data,"od.poisson.response")
 #	data.paid	<- data.loss.XL()
 #	apc.fit.table(data.paid,"od.poisson.response")
 #	apc.fit.table(data,"poisson.response")
