@@ -152,25 +152,28 @@ apc.forecast.ac <- function(apc.fit,sum.per.by.age=NULL,sum.per.by.coh=NULL,quan
 							per.zero	=  per.zero			,
 							per.odd		=  per.odd			,
 							U			=  U				,
-							n.data		=  n.data.J			)
+							n.data		=  n.data.J			,
+							data.format = "trapezoid")             # BN 27 jun 2025 added
 	#	get design matrix
    	design.J	<- apc.get.design(apc.index.J,model.design)$design
 	##############################
 	#	Get design for sample area
 	#	apc index list for sample area
-	apc.index	<- list(	age.max		=  age.max			,		
-							per.max		=  per.max			,
-							coh.max		=  coh.max			,
-							age1		=  age1				,	# this entry used in intercept correction
-							per1		=  per1				,	# this entry used in intercept correction
-							coh1		=  coh1				,	# this entry used in intercept correction
-							unit		=  unit				,	# this entry used in intercept correction
-							index.trap	=  index.trap 		,
+	apc.index	<- list(	
+	            age.max		  =  age.max			,		
+							per.max	  	=  per.max			,
+							coh.max		  =  coh.max			,
+							age1    		=  age1	  			,	# this entry used in intercept correction
+							per1		    =  per1			  	,	# this entry used in intercept correction
+							coh1    		=  coh1				  ,	# this entry used in intercept correction
+							unit		    =  unit				  ,	# this entry used in intercept correction
+							index.trap	=  index.trap 	,
 							index.data	=  index.data		,	# this entry used in intercept correction
-							per.zero	=  per.zero			,
-							per.odd		=  per.odd			,
-							U			=  U				,
-							n.data		=  n.data			)	
+							per.zero  	=  per.zero			,
+							per.odd		  =  per.odd			,
+							U     			=  U			    	,
+							n.data  		=  n.data			  ,
+							data.format = "trapezoid"        )   # BN 27 jun 2025 added
 	#	get design matrix
    	design	<- apc.get.design(apc.index,model.design)$design
 	##############################
@@ -294,9 +297,9 @@ apc.forecast.ac <- function(apc.fit,sum.per.by.age=NULL,sum.per.by.coh=NULL,quan
 			s	<- s + row
 		}
 		#	labels
-		label.age	<- c(paste("age_",apc.internal.function.date.2.character(age1+seq(age.max-per.forecast.J,age.max-1)*unit,n.decimal),sep=""))
-		label.per	<- c(paste("per_",apc.internal.function.date.2.character(per1+seq(per.max,per.max+per.forecast.J-1)*unit,n.decimal),sep=""))
-		label.coh	<- c(paste("coh_",apc.internal.function.date.2.character(coh1+seq(coh.max-per.forecast.J,coh.max-1)*unit,n.decimal),sep=""))
+		label.age	<- c(paste("age_",apc.internal.function.date.2.character(age1+seq(age.max-per.forecast.J,age.max-1)*unit[1],n.decimal),sep=""))		# 24 Jun 2025, unit updated	
+		label.per	<- c(paste("per_",apc.internal.function.date.2.character(per1+seq(per.max,per.max+per.forecast.J-1)*unit[1],n.decimal),sep=""))
+		label.coh	<- c(paste("coh_",apc.internal.function.date.2.character(coh1+seq(coh.max-per.forecast.J,coh.max-1)*unit[1],n.decimal),sep=""))
 		label.all	<-  "all"                                                                               	
 		#	forecasts
 		response.forecast.age	<- function.sum.forecasts(m.partial.sum.age,label.age)
@@ -347,7 +350,7 @@ apc.forecast.ac <- function(apc.fit,sum.per.by.age=NULL,sum.per.by.coh=NULL,quan
 				 	m.partial.sum.per.by.age[per,s+per]		<- 1
 				s	<- s + row
 			}
-			label.sum	<- c(paste("per_",apc.internal.function.date.2.character(per1+seq(per.max,per.max+sum.length-1)*unit,n.decimal),sep=""))
+			label.sum	<- c(paste("per_",apc.internal.function.date.2.character(per1+seq(per.max,per.max+sum.length-1)*unit[1],n.decimal),sep=""))	# 24 Jun 2025, unit updated	
 			sum.per.by.age	<- function.sum.forecasts(m.partial.sum.per.by.age,label.sum)
 			sum.per.by.age.ic		<- sum.per.by.age
 			sum.per.by.age.ic[,1]	<- sum.per.by.age.ic[,1] * intercept.correction.per.by.age
@@ -355,7 +358,7 @@ apc.forecast.ac <- function(apc.fit,sum.per.by.age=NULL,sum.per.by.coh=NULL,quan
 		#	by cohort
 		if(is.null(sum.per.by.coh)==FALSE)
 		{	#	for intercept correction
-			data.data.trunc	<- apc.data.list.subset(list(response=response,data.format=data.format,dose=NULL)		,0,0,0,0,sum.per.by.coh[1]-1,coh.max-sum.per.by.coh[2],apc.index,TRUE)
+			data.data.trunc	<- apc.data.list.subset(list(response=response,data.format=data.format,dose=NULL),0,0,0,0,sum.per.by.coh[1]-1,coh.max-sum.per.by.coh[2],apc.index,TRUE)
 			data.fit.trunc	<- apc.data.list.subset(list(response=m.fitted.values,data.format=data.format,dose=NULL),0,0,0,0,sum.per.by.coh[1]-1,coh.max-sum.per.by.coh[2],apc.index,TRUE)
 			if(sum.per.by.coh[1]==sum.per.by.coh[2])
 			{
@@ -379,7 +382,7 @@ apc.forecast.ac <- function(apc.fit,sum.per.by.age=NULL,sum.per.by.coh=NULL,quan
 				 	m.partial.sum.per.by.coh[per,s+per]		<- 1
 				s	<- s + sum.discard + row
 			}
-			label.sum	<- c(paste("per_",apc.internal.function.date.2.character(per1+seq(per.max,per.max+sum.length-1)*unit,n.decimal),sep=""))
+			label.sum	<- c(paste("per_",apc.internal.function.date.2.character(per1+seq(per.max,per.max+sum.length-1)*unit[1],n.decimal),sep=""))	# 24 Jun 2025, unit updated	
 			sum.per.by.coh	<- function.sum.forecasts(m.partial.sum.per.by.coh,label.sum)
 			sum.per.by.coh.ic		<- sum.per.by.coh
 			sum.per.by.coh.ic[,1]	<- sum.per.by.coh.ic[,1] * intercept.correction.per.by.coh
@@ -505,7 +508,7 @@ apc.forecast.ap <- function(apc.fit,extrapolation.type="I0",suppress.warning=TRU
 	#		thus Delpa.beta_{per.max+h} = 0 for h>1
 	D.xi.per.extrapolated		<- matrix(data=0,nrow=per.forecast.J,ncol=1)
 	#	Add labels	12 Apr 2016
-	rownames(D.xi.per.extrapolated)	<- paste("D_period",apc.internal.function.date.2.character(per1+(per.max-1+seq(1,per.forecast.J))*unit,n.decimal),sep="")
+	rownames(D.xi.per.extrapolated)	<- paste("D_period",apc.internal.function.date.2.character(per1+(per.max-1+seq(1,per.forecast.J))*unit[1],n.decimal),sep="")	# 24 Jun 2025, unit updated	
 	#   I0 forecast	
 	if(extrapolation.type=="I0")
 	{	D.xi.per	<- coefficients.dif[index.per.dif]
@@ -651,9 +654,10 @@ apc.forecast.apc <- function(apc.fit,extrapolation.type="I0",suppress.warning=TR
 							per.zero	=  per.zero			,
 							per.odd		=  per.odd			,
 							U			=  U				,
-							n.data		=  n.data.J			)
+							n.data		=  n.data.J			,
+							data.format = "trapezoid")             # BN 27 jun 2025 added
 	#	get design matrix
-   	design.J	<- apc.get.design(apc.index.J,model.design)$design
+	  	design.J	<- apc.get.design(apc.index.J,model.design)$design
 	##############################
 	#	Extrapolate period parameters
 	#	get estimates
@@ -661,7 +665,7 @@ apc.forecast.apc <- function(apc.fit,extrapolation.type="I0",suppress.warning=TR
 	#	define extrapolation array
 	xi.per.dd.extrapolated <- matrix(data=0,nrow=per.forecast.J,ncol=1)
 	#	add row names
-	rownames(xi.per.dd.extrapolated)	<- paste("DD_period_",apc.internal.function.date.2.character(per1+(per.max-1+seq(1,per.forecast.J))*unit,n.decimal),"_x",sep="")
+	rownames(xi.per.dd.extrapolated)	<- paste("DD_period_",apc.internal.function.date.2.character(per1+(per.max-1+seq(1,per.forecast.J))*unit[1],n.decimal),"_x",sep="")	# 24 Jun 2025, unit updated	
 	#	extrapolation.type == "I2"
 	#	nothing happens
 	#	extrapolation.type == "I1"
@@ -722,9 +726,9 @@ apc.forecast.apc <- function(apc.fit,extrapolation.type="I0",suppress.warning=TR
 		response.forecast.coh	<- m.partial.sum.coh %*% exp( design.J %*% xi.extrapolated[,] )
 		response.forecast.all	<- m.partial.sum.all %*% exp( design.J %*% xi.extrapolated[,] )
 		#	labels
-		label.age	<- c(paste("age_",apc.internal.function.date.2.character(age1+seq(age.max-per.forecast.J,age.max-1)*unit,n.decimal),sep=""))
-		label.per	<- c(paste("per_",apc.internal.function.date.2.character(per1+seq(per.max,per.max+per.forecast.J-1)*unit,n.decimal),sep=""))
-		label.coh	<- c(paste("coh_",apc.internal.function.date.2.character(coh1+seq(coh.max-per.forecast.J,coh.max-1)*unit,n.decimal),sep=""))
+		label.age	<- c(paste("age_",apc.internal.function.date.2.character(age1+seq(age.max-per.forecast.J,age.max-1)*unit[1],n.decimal),sep=""))	# 24 Jun 2025, unit updated	
+		label.per	<- c(paste("per_",apc.internal.function.date.2.character(per1+seq(per.max,per.max+per.forecast.J-1)*unit[1],n.decimal),sep=""))
+		label.coh	<- c(paste("coh_",apc.internal.function.date.2.character(coh1+seq(coh.max-per.forecast.J,coh.max-1)*unit[1],n.decimal),sep=""))
 		label.all	<-  "all"
 		rownames(response.forecast.age)	<- label.age
 		rownames(response.forecast.per)	<- label.per
@@ -791,7 +795,7 @@ apc.polygon <- function(m.forecast,x.origin=1,
 #        density.se		Standard error polygon: 3-vector: Density of shading. Same as density 	for polygon. Default: =c(NULL,NULL,NULL).
 #        lty.se			Standard error polygon: 3-vector: Type of shading.    Same as lty 		for polygon. Default: =c(1,1,1).
 {   #	apc.polygon 
-  	x   <- seq(x.origin+unit,by=unit,length=nrow(m.forecast))
+  	x   <- seq(x.origin+unit[1],by=unit,length=nrow(m.forecast))	# 24 Jun 2025, unit updated	
   	polygon.forecast <- function(se.choice)
   	{	polygon(c(x,rev(x)),
 				c(m.forecast[,1]+q.se[se.choice]*m.forecast[,se.choice+1],
