@@ -1,5 +1,6 @@
 #######################################################
 #	apc package
+# Bent Nielsen, 24 June 2025, version 3.0.0
 #	Bent Nielsen, 28 September 2020, version 2.0.0
 #	Bent Nielsen, 7 May 2017, version 1.3.1
 #	functions to identify parameters
@@ -25,7 +26,8 @@
 #########################################################
 #	apc.identify
 #########################################################
-apc.identify	<- function(apc.fit.model)
+apc.identify	<- function(apc.fit.model)	
+# BN		24 jun 2025 Updated to new unit for mixed frequency
 #	BN/ZF  20 sep 2020	Subsumed var.apc.identify for apc.indiv
 #	BN		7 may 2017	Changed: covariance for OD.Poisson scaled correctly
 #	BN  	2 feb 2016	Changed: parameter label: date to character changed to allow nice decimal points
@@ -131,26 +133,26 @@ apc.identify	<- function(apc.fit.model)
 	#	construct dates for for double difference parameters 
 	#	first for use with (double difference) canonical parameters
 	dates.max		<- matrix(data=NA,nrow=xi.max,ncol=1)
-	if(difdif[1])	dates.max[index.age.max,1]	<- age1+seq(0,age.max-1)*unit	
-	if(difdif[2])	dates.max[index.per.max,1]	<- per1+seq(0,per.max-1)*unit
-	if(difdif[3])	dates.max[index.coh.max,1]	<- coh1+seq(0,coh.max-1)*unit
+	if(difdif[1])	dates.max[index.age.max,1]	<- age1+seq(0,age.max-1)*unit[1]	# 24 Jun 2025, unit updated	
+	if(difdif[2])	dates.max[index.per.max,1]	<- per1+seq(0,per.max-1)*unit[1]
+	if(difdif[3])	dates.max[index.coh.max,1]	<- coh1+seq(0,coh.max-1)*unit[1]
 	#	then for use with in reparametrised submodels of sums of differences 
 	dates.sub		<- NULL
 	if(!(model.design %in% c("APC","FAP")))		# BN/ZF 250920 exclude FAP
 	{
 		dates.sub		<- matrix(data=NA,nrow=xi.sub,ncol=1)
-		if(difdif[1])	dates.sub[index.age.sub,1]	<- age1+seq(0,age.max-1)*unit	
-		if(difdif[2])	dates.sub[index.per.sub,1]	<- per1+seq(0,per.max-1)*unit
-		if(difdif[3])	dates.sub[index.coh.sub,1]	<- coh1+seq(0,coh.max-1)*unit
+		if(difdif[1])	dates.sub[index.age.sub,1]	<- age1+seq(0,age.max-1)*unit[1]	# 24 Jun 2025, unit updated	
+		if(difdif[2])	dates.sub[index.per.sub,1]	<- per1+seq(0,per.max-1)*unit[1]
+		if(difdif[3])	dates.sub[index.coh.sub,1]	<- coh1+seq(0,coh.max-1)*unit[1]
 	}	
 	#	then for use with in reparametrised submodels of sums of differences 
 	dates.dif		<- NULL
 	if(!(model.design %in% c("APC","FAP")))		# BN/ZF 250920 exclude FAP
 	{
 		dates.dif		<- matrix(data=NA,nrow=xi.dif,ncol=1)
-		if(difdif[1])	dates.dif[index.age.dif,1]	<- age1+seq(1,age.max-1)*unit	
-		if(difdif[2])	dates.dif[index.per.dif,1]	<- per1+seq(1,per.max-1)*unit
-		if(difdif[3])	dates.dif[index.coh.dif,1]	<- coh1+seq(1,coh.max-1)*unit
+		if(difdif[1])	dates.dif[index.age.dif,1]	<- age1+seq(1,age.max-1)*unit[1]	# 24 Jun 2025, unit updated	
+		if(difdif[2])	dates.dif[index.per.dif,1]	<- per1+seq(1,per.max-1)*unit[1]
+		if(difdif[3])	dates.dif[index.coh.dif,1]	<- coh1+seq(1,coh.max-1)*unit[1]
 	}	
 	##############################
 	#	get linear transformation matrix
