@@ -172,11 +172,11 @@ apc.plot.fit	<- function(apc.fit.model,scale=FALSE,sdv.at.zero=TRUE,type="detren
 		l.dates[[2]]	<- dates[index.per,1]
 		l.dates[[3]]	<- dates[index.coh,1]
 		if(model.design %in% c("APC","AP","AC","PC","Ad","Pd","Cd","t","A","tA",l.model.F))
-			l.dates[[4]]	<- age1+seq(0,age.max-1)*unit
+			l.dates[[4]]	<- age1+seq(0,age.max-1)*unit[1]		# 24 Jun 2025, unit updated
 		if(model.design %in% c("P","tP"))									
-			l.dates[[4]]	<- per1+seq(0,per.max-1)*unit
+			l.dates[[4]]	<- per1+seq(0,per.max-1)*unit[1]		# 24 Jun 2025, unit updated
 		l.dates[[5]]	<- c(0,1)  # matrix(data=c(0,1)		     ,nrow=2	  ,ncol=1)
-		l.dates[[6]]	<- coh1+seq(0,coh.max-1)*unit
+		l.dates[[6]]	<- coh1+seq(0,coh.max-1)*unit[1]			# 24 Jun 2025, unit updated
 		l.dates[[7]]	<- dates.max[index.age.max,1]
 		l.dates[[8]]	<- dates.max[index.per.max,1]
 		l.dates[[9]]	<- dates.max[index.coh.max,1]		
@@ -510,9 +510,9 @@ apc.plot.fit.pt	<- function(apc.fit.model,do.plot=TRUE,do.value=FALSE,pch=c(21,2
 		if(is.null(bg)==TRUE)	bg <- col	
 		####################
 		#	limits for axes
-		xlim	<- c(x1,x1 +(xmax-1)*unit)
-		if(data.format=="CL")	ylim	<- c(y1 +(ymax-1)*unit,y1)	
-		else					ylim	<- c(y1,y1 +(ymax-1)*unit)
+		xlim	<- c(x1,x1 +(xmax-1)*unit[1])
+		if(data.format=="CL")	ylim	<- c(y1 +(ymax-1)*unit[1],y1)		# 24 Jun 2025, unit updated
+		else									ylim	<- c(y1,y1 +(ymax-1)*unit[1])
 		####################
 		#	plot parameters
 		par(mfrow=c(1,1))		
@@ -523,8 +523,8 @@ apc.plot.fit.pt	<- function(apc.fit.model,do.plot=TRUE,do.value=FALSE,pch=c(21,2
 		for(row in 1:xmax)
 			for(column in 1:ymax)
 			{
-				x	<- x1+(row-1)*unit				#	get x coordinate
-				y	<- y1+(column-1)*unit			#	get y coordinate
+				x	<- x1+(row	 -1)*unit[1]		#	get x coordinate		# 24 Jun 2025, unit updated
+				y	<- y1+(column-1)*unit[1]		#	get y coordinate
 				z	<- m.pt.fit[row,column]			#	get probability transform of fit
 				if(is.na(z)==FALSE)
 				{				
